fit.ghypmv(data, lambda = 1, alpha.bar = 1, mu = NULL, sigma = NULL,
gamma = NULL, opt.pars = c(lambda = T, alpha.bar = T, mu = T,
sigma = T, gamma = !symmetric),
symmetric = F, standardize = F, nit = 2000, reltol = 1e-8,
abstol = reltol * 10, na.rm = F, silent = FALSE, save.data = T,
trace = TRUE, ...)
fit.hypmv(data,
opt.pars = c(alpha.bar = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)fit.NIGmv(data,
opt.pars = c(alpha.bar = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.VGmv(data, lambda = 1,
opt.pars = c(lambda = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.tmv(data, nu = 3.5,
opt.pars = c(lambda = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.gaussmv(data, na.rm = T, save.data = T)
matrix.lambda.alpha.bar.nu (only used in case of a student-t distribution. It determines
the degree of freedom and is defined as -2*lambda.)mu.sigma.gamma.vector which states which parameters should be fitted.TRUE the skewness parameter gamma keeps zero.TRUE the sample will be standardized before fitting.
Afterwards, the parameters and log-likelihood et cetera will be back-transformed.TRUE the evolution of the parameter values during the fitting procedure
will be traced and stored (cf. ghyp.fit.info).TRUE missing values will be removed from data.TRUE no prompts will appear in the console.optim and to fit.ghypmv when
fitting special cases of the generalized hyperbolic distribution.mle.ghyp.doc folder. A more detailed description is provided
by the book Quantitative Risk Management, Concepts, Techniques and Tools
(see optim is used to maximize
the loglikelihood function of the univariate mixing distribution.
The default method is that of Nelder and Mead which
uses only function values. Parameters of optim can be passed via
the ...argument of the fitting routines.ghyp-package vignette in the doc folder or on fit.ghypuv, fit.hypuv, fit.NIGuv,
fit.VGuv, fit.tuv for univariate fitting routines.data(smi.stocks)
fit.ghypmv(data = smi.stocks, opt.pars = c(lambda = FALSE), lambda = 2,
control = list(rel.tol = 1e-5, abs.tol = 1e-5), reltol = 0.01)Run the code above in your browser using DataLab