Learn R Programming

ghyp (version 1.5.6)

logLik-AIC-methods: Extract Log-Likelihood and Akaike's Information Criterion

Description

The functions logLik and AIC extract the Log-Likelihood and the Akaike's Information Criterion from fitted generalized hyperbolic distribution objects. The Akaike information criterion is calculated according to the formula $-2 * log-likelihood + k * npar$, where $npar$ represents the number of parameters in the fitted model, and $k = 2$ for the usual AIC.

Usage

"logLik"(object, ...)
"AIC"(object, ..., k = 2)

Arguments

object
An object of class mle.ghyp.
k
The “penalty” per parameter to be used; the default k = 2 is the classical AIC.
...
An arbitrary number of objects of class mle.ghyp.

Value

Either the Log-Likelihood or the Akaike's Information Criterion.

See Also

fit.ghypuv, fit.ghypmv, lik.ratio.test, ghyp.fit.info, mle.ghyp-class

Examples

Run this code
  data(smi.stocks)

  ## Multivariate fit
  fit.mv <- fit.hypmv(smi.stocks, nit = 10)
  AIC(fit.mv)
  logLik(fit.mv)

  ## Univariate fit
  fit.uv <- fit.tuv(smi.stocks[, "CS"], control = list(maxit = 10))
  AIC(fit.uv)
  logLik(fit.uv)

  # Both together
  AIC(fit.uv, fit.mv)
  logLik(fit.uv, fit.mv)

Run the code above in your browser using DataLab