fit.ghypuv(data, lambda = 1, alpha.bar = 0.5, mu = median(data),
sigma = mad(data), gamma = 0,
opt.pars = c(lambda = T, alpha.bar = T, mu = T,
sigma = T, gamma = !symmetric),
symmetric = F, standardize = F, save.data = T,
na.rm = T, silent = FALSE, ...)
fit.hypuv(data,
opt.pars = c(alpha.bar = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.NIGuv(data,
opt.pars = c(alpha.bar = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.VGuv(data, lambda = 1,
opt.pars = c(lambda = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.tuv(data, nu = 3.5,
opt.pars = c(nu = T, mu = T, sigma = T, gamma = !symmetric),
symmetric = F, ...)
fit.gaussuv(data, na.rm = T, save.data = T)vector.lambda.alpha.bar.nu (only used in case of a student-t distribution. It determines
the degree of freedom and is defined as -2*lambda.)mu.sigma.gamma.vector which states which parameters should be fitted.TRUE the skewness parameter gamma keeps zero.TRUE the sample will be standardized before fitting.
Afterwards, the parameters and log-likelihood et cetera will be back-transformed.TRUE data will be stored within the
mle.ghyp object.TRUE missing values will be removed from data.TRUE no prompts will appear in the console.optim and to fit.ghypuv when
fitting special cases of the generalized hyperbolic distribution.mle.ghyp.optim is used to maximize
the loglikelihood function. The default method is that of Nelder and Mead which
uses only function values. Parameters of optim can be passed via
the ...argument of the fitting routines.ghyp-package vignette in the doc folder or on fit.ghypmv, fit.hypmv, fit.NIGmv,
fit.VGmv, fit.tmv for multivariate fitting routines.data(smi.stocks)
nig.fit <- fit.NIGuv(smi.stocks[,"SMI"], opt.pars = c(alpha.bar = FALSE),
alpha.bar = 1, control = list(abs.tol = 1e-8))
nig.fit
summary(nig.fit)
hist(nig.fit)Run the code above in your browser using DataLab