This function is intended to be used as a graphical diagnostic tool for fitted univariate generalized hyperbolic distributions. Optionally a qq-plot of the normal distribution can be added.
qqghyp(object, data = ghyp.data(object), gaussian = TRUE, line = TRUE, main = "Generalized Hyperbolic Q-Q Plot", xlab = "Theoretical Quantiles", ylab = "Sample Quantiles", ghyp.pch = 1, gauss.pch = 6, ghyp.lty = "solid", gauss.lty = "dashed", ghyp.col = "black", gauss.col = "black", plot.legend = TRUE, location = "topleft", legend.cex = 0.8, spline.points = 150, root.tol = .Machine$double.eps^0.5, rel.tol = root.tol, abs.tol = root.tol^1.5, add = FALSE, ...)vector.TRUE a qq-plot of the normal distribution is plotted as a reference.TRUE a line is fitted and drawn.TRUE a legend is drawn.legend for possible values.qghyp.uniroot.integrate.integrate.TRUE the points are added to an existing plot window. The legend argument then becomes deactivated.plot.hist, fit.ghypuv, qghyp,
plot,
lines data(smi.stocks)
smi <- fit.ghypuv(data = smi.stocks[, "Swiss.Re"])
qqghyp(smi, spline.points = 100)
qqghyp(fit.tuv(smi.stocks[, "Swiss.Re"], symmetric = TRUE),
add = TRUE, ghyp.col = "red", line = FALSE)
Run the code above in your browser using DataLab